%bcond_with    x86only          # disabled
%bcond_with    exclusive_x86_64 # disabled
%bcond_without rbd              # enabled
%bcond_without fdt              # enabled
%bcond_without seccomp

# Enable SPICE support unless it is disabled in branding-configs.
%{?build_spice}%{?!build_spice:%bcond_without spice}

%define _disable_ld_no_undefined 1

%define _udevdir /lib/udev/rules.d
%define qemudocdir %{_docdir}/%{name}

Summary:	QEMU CPU Emulator
Name:		qemu
Version:	2.5.1.1
Release:	1
License:	GPLv2+ and LGPLv2+ and BSD
Group:		Emulators
Url:		http://wiki.qemu.org/Main_Page
Source0:	http://wiki.qemu.org/download/%{name}-%{version}.tar.bz2
Source1:	qemu.binfmt
# Creates /dev/kvm
Source3:	80-kvm.rules
# KSM control scripts
Source4:	ksm.service
Source5:	ksm.sysconfig
Source6:	ksmctl.c
Source7:	ksmtuned.service
Source8:	ksmtuned
Source9:	ksmtuned.conf
# End of KSM control scripts
Source10:	qemu-guest-agent.service
Source11:	99-qemu-guest-agent.rules
Source12:	bridge.conf
# qemu-kvm backward compatibility wrapper
Source13:	qemu-kvm.sh
Source100:	qemu.rpmlintrc

# From Mageia
Patch01:	CVE-2016-2198-usb-ehci-add-capability-mmio-write-function.patch
Patch02:	CVE-2016-2391-ohci-allocate-timer-only-once.patch
Patch03:	CVE-2016-2858-01-rng-remove-the-unused-request-cancellation-code.patch
Patch04:	CVE-2016-2858-02-rng-move-request-queue-from-RngEgd-to-RngBackend.patch
Patch05:	CVE-2016-2858-03-rng-move-request-queue-cleanup-from-RngEgd-to-RngBac.patch
Patch06:	CVE-2016-2858-04-rng-add-request-queue-support-to-rng-random.patch
Patch07:	CVE-2016-4001-net-stellaris_enet-check-packet-length-against-receive.patch
Patch08:	CVE-2016-4002.patch
Patch09:	CVE-2016-4020.patch

BuildRequires:	iasl
BuildRequires:	kernel-headers
BuildRequires:	libtool
BuildRequires:	rsync
BuildRequires:	texi2html
BuildRequires:	texinfo
BuildRequires:	attr-devel
BuildRequires:	bzip2-devel
BuildRequires:	cap-devel
BuildRequires:	jpeg-devel
BuildRequires:	libaio-devel
BuildRequires:	numa-devel
BuildRequires:	sasl-devel
BuildRequires:	usbredir-devel >= 0.5.2
BuildRequires:	xfsprogs-devel
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(bluez)
BuildRequires:	pkgconfig(epoxy)
BuildRequires:	pkgconfig(gnutls) >= 3.0
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(libcap-ng)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libpci)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libprofiler)
BuildRequires:	pkgconfig(libpulse)
%if %{with seccomp}
BuildRequires:	pkgconfig(libseccomp) >= 2.1.0
%endif
BuildRequires:	pkgconfig(libssh2)
BuildRequires:	pkgconfig(libusb-1.0)
BuildRequires:	pkgconfig(libusbredirhost) >=0.5.2
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(nss)
BuildRequires:	pkgconfig(pixman-1)
BuildRequires:	pkgconfig(sdl2)
%if %{with spice}
BuildRequires:	pkgconfig(spice-server)
BuildRequires:	pkgconfig(spice-protocol)
%endif
BuildRequires:	pkgconfig(uuid)
BuildRequires:	pkgconfig(vdeplug)
BuildRequires:	pkgconfig(vte-2.90)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(egl)

Requires:	cyrus-sasl
Requires:	ipxe-roms-qemu >= 20150803
Requires:	qemu-img = %{EVRD}
Requires:	seavgabios-bin
Requires:	seabios-bin >= 1.7.5
Requires:	sgabios-bin
Requires(post,preun,postun):	systemd-units
%rename		kvm

ExclusiveArch:	%{ix86} x86_64

%description
QEMU is a generic and open source processor emulator which achieves a good
emulation speed by using dynamic translation. QEMU has two operating modes:

* Full system emulation. In this mode, QEMU emulates a full system (for
  example a PC), including a processor and various peripherials. It can be
  used to launch different Operating Systems without rebooting the PC or
  to debug system code.
* User mode emulation. In this mode, QEMU can launch Linux processes compiled
  for one CPU on another CPU.

QEMU requires no host kernel patches to run, it is safe and easy to use.

%files -f %{name}.lang
# common
%dir %{qemudocdir}
%doc %{qemudocdir}/Changelog
%doc %{qemudocdir}/README
%doc %{qemudocdir}/qemu-doc.html
%doc %{qemudocdir}/qemu-tech.html
%doc %{qemudocdir}/qmp-commands.txt
%doc %{qemudocdir}/COPYING
%doc %{qemudocdir}/COPYING.LIB
%doc %{qemudocdir}/LICENSE
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/qemu-icon.bmp
%{_datadir}/%{name}/qemu_logo_no_text.svg
%{_datadir}/%{name}/keymaps/
%{_datadir}/%{name}/trace-events
%{_mandir}/man1/qemu.1*
%{_mandir}/man1/virtfs-proxy-helper.1*
%{_bindir}/virtfs-proxy-helper
%attr(4755, root, root) %{_libexecdir}/qemu-bridge-helper
%config(noreplace) %{_sysconfdir}/sasl2/qemu.conf
%dir %{_sysconfdir}/qemu
%config(noreplace) %{_sysconfdir}/qemu/bridge.conf
# ksm
%{_libexecdir}/ksmctl
%{_sbindir}/ksmtuned
%{_unitdir}/ksmtuned.service
%{_unitdir}/ksm.service
%config(noreplace) %{_sysconfdir}/ksmtuned.conf
%config(noreplace) %{_sysconfdir}/sysconfig/ksm
# guest-agent
%{_bindir}/qemu-ga
%{_mandir}/man8/qemu-ga.8*
%{_unitdir}/qemu-guest-agent.service
%{_udevdir}/99-qemu-guest-agent.rules
# emulators, etc.
%{_exec_prefix}/lib/binfmt.d/qemu-*.conf
%{_bindir}/qemu-i386
%{_bindir}/qemu-x86_64
%{_bindir}/qemu-aarch64
%{_bindir}/qemu-alpha
%{_bindir}/qemu-arm
%{_bindir}/qemu-armeb
%{_bindir}/qemu-cris
%{_bindir}/qemu-m68k
%{_bindir}/qemu-microblaze
%{_bindir}/qemu-microblazeel
%{_bindir}/qemu-mips
%{_bindir}/qemu-mipsel
%{_bindir}/qemu-mips64
%{_bindir}/qemu-mips64el
%{_bindir}/qemu-mipsn32
%{_bindir}/qemu-mipsn32el
%{_bindir}/qemu-or32
%{_bindir}/qemu-ppc
%{_bindir}/qemu-ppc64
%{_bindir}/qemu-ppc64abi32
%{_bindir}/qemu-ppc64le
%{_bindir}/qemu-s390x
%{_bindir}/qemu-sh4
%{_bindir}/qemu-sh4eb
%{_bindir}/qemu-sparc
%{_bindir}/qemu-sparc32plus
%{_bindir}/qemu-sparc64
%{_bindir}/qemu-unicore32
# KVM
%ifarch %{ix86} x86_64
%{_bindir}/qemu-kvm
%{_bindir}/kvm_stat
%{_mandir}/man1/qemu-kvm.1*
%{_udevdir}/80-kvm.rules
%endif
# x86
%{_bindir}/qemu-system-i386
%{_bindir}/qemu-system-x86_64
%{_mandir}/man1/qemu-system-i386.1*
%{_mandir}/man1/qemu-system-x86_64.1*
%{_datadir}/%{name}/acpi-dsdt.aml
%{_datadir}/%{name}/q35-acpi-dsdt.aml
%{_datadir}/%{name}/bios.bin
%{_datadir}/%{name}/bios-256k.bin
%{_datadir}/%{name}/sgabios.bin
%{_datadir}/%{name}/linuxboot.bin
%{_datadir}/%{name}/multiboot.bin
%{_datadir}/%{name}/kvmvapic.bin
%{_datadir}/%{name}/vgabios.bin
%{_datadir}/%{name}/vgabios-cirrus.bin
%{_datadir}/%{name}/vgabios-qxl.bin
%{_datadir}/%{name}/vgabios-stdvga.bin
%{_datadir}/%{name}/vgabios-vmware.bin
%{_datadir}/%{name}/vgabios-virtio.bin
%{_datadir}/%{name}/pxe-e1000.rom
%{_datadir}/%{name}/efi-e1000.rom
%{_datadir}/%{name}/pxe-virtio.rom
%{_datadir}/%{name}/efi-virtio.rom
%{_datadir}/%{name}/pxe-pcnet.rom
%{_datadir}/%{name}/efi-pcnet.rom
%{_datadir}/%{name}/pxe-rtl8139.rom
%{_datadir}/%{name}/efi-rtl8139.rom
%{_datadir}/%{name}/pxe-ne2k_pci.rom
%{_datadir}/%{name}/efi-ne2k_pci.rom
# alpha
%{_bindir}/qemu-system-alpha
%{_mandir}/man1/qemu-system-alpha.1*
%{_datadir}/%{name}/palcode-clipper
# arm
%{_bindir}/qemu-system-arm
%{_mandir}/man1/qemu-system-arm.1*
# mips
%{_bindir}/qemu-system-mips
%{_bindir}/qemu-system-mipsel
%{_bindir}/qemu-system-mips64
%{_bindir}/qemu-system-mips64el
%{_mandir}/man1/qemu-system-mips.1*
%{_mandir}/man1/qemu-system-mipsel.1*
%{_mandir}/man1/qemu-system-mips64el.1*
%{_mandir}/man1/qemu-system-mips64.1*
# cris
%{_bindir}/qemu-system-cris
%{_mandir}/man1/qemu-system-cris.1*
# lm32
%{_bindir}/qemu-system-lm32
%{_mandir}/man1/qemu-system-lm32.1*
# m68k
%{_bindir}/qemu-system-m68k
%{_mandir}/man1/qemu-system-m68k.1*
# microblaze
%{_bindir}/qemu-system-microblaze
%{_bindir}/qemu-system-microblazeel
%{_mandir}/man1/qemu-system-microblaze.1*
%{_mandir}/man1/qemu-system-microblazeel.1*
%{_datadir}/%{name}/petalogix*.dtb
# or32
%{_bindir}/qemu-system-or32
%{_mandir}/man1/qemu-system-or32.1*
# s390x
%{_bindir}/qemu-system-s390x
%{_mandir}/man1/qemu-system-s390x.1*
%{_datadir}/%{name}/s390-zipl.rom
%{_datadir}/%{name}/s390-ccw.img
# sh4
%{_bindir}/qemu-system-sh4
%{_bindir}/qemu-system-sh4eb
%{_mandir}/man1/qemu-system-sh4.1*
%{_mandir}/man1/qemu-system-sh4eb.1*
# sparc
%{_bindir}/qemu-system-sparc
%{_bindir}/qemu-system-sparc64
%{_mandir}/man1/qemu-system-sparc.1*
%{_mandir}/man1/qemu-system-sparc64.1*
%{_datadir}/%{name}/QEMU,tcx.bin
%{_datadir}/%{name}/QEMU,cgthree.bin
# ppc
%{_bindir}/qemu-system-ppc
%{_bindir}/qemu-system-ppc64
%{_bindir}/qemu-system-ppcemb
%{_mandir}/man1/qemu-system-ppc.1*
%{_mandir}/man1/qemu-system-ppc64.1*
%{_mandir}/man1/qemu-system-ppcemb.1*
%{_datadir}/%{name}/bamboo.dtb
%{_datadir}/%{name}/ppc_rom.bin
%{_datadir}/%{name}/spapr-rtas.bin
%{_datadir}/%{name}/u-boot.e500
# unicore32
%{_bindir}/qemu-system-unicore32
%{_mandir}/man1/qemu-system-unicore32.1*
# xtensa
%{_bindir}/qemu-system-xtensa
%{_bindir}/qemu-system-xtensaeb
%{_mandir}/man1/qemu-system-xtensa.1*
%{_mandir}/man1/qemu-system-xtensaeb.1*
# moxie
%{_bindir}/qemu-system-moxie
%{_mandir}/man1/qemu-system-moxie.1*
# aarch64
%{_bindir}/qemu-system-aarch64
%{_mandir}/man1/qemu-system-aarch64.1*
# tricore
%{_bindir}/qemu-system-tricore
%{_mandir}/man1/qemu-system-tricore.1*

%post
getent group kvm >/dev/null || groupadd -g 36 -r kvm
getent group qemu >/dev/null || groupadd -g 107 -r qemu
getent passwd qemu >/dev/null || \
  useradd -r -u 107 -g qemu -G kvm -d / -s /sbin/nologin \
    -c "qemu user" qemu

%ifarch %{ix86} x86_64
# A workaround for https://bugzilla.redhat.com/show_bug.cgi?id=950436
chmod --quiet 666 /dev/kvm || :
%endif

%systemd_post ksmtuned.service
%systemd_post ksm.service
%systemd_post qemu-guest-agent.service

systemctl --system try-restart systemd-binfmt.service &>/dev/null || :

%preun
%systemd_preun ksm.service
%systemd_preun ksmtuned.service
%systemd_preun qemu-guest-agent.service

%postun
%systemd_postun_with_restart systemd-binfmt.service

#----------------------------------------------------------------------------

%package img
Summary:	QEMU disk image utility
Group:		Emulators
Conflicts:	qemu < 0.9.0-3

%description img
This package contains the QEMU disk image utility that is used to
create, commit, convert and get information from a disk image.

%files img
%{_bindir}/qemu-img
%{_bindir}/qemu-io
%{_bindir}/qemu-nbd
%{_mandir}/man1/qemu-img.1*
%{_mandir}/man8/qemu-nbd.8*

#----------------------------------------------------------------------------

%package -n ivshmem-tools
Summary:	Client and server for QEMU ivshmem device
Group:		Emulators

%description -n ivshmem-tools
This package provides client and server tools for QEMU's ivshmem device.

%files -n ivshmem-tools
%{_bindir}/ivshmem-client
%{_bindir}/ivshmem-server

#----------------------------------------------------------------------------

%prep
%setup -q -n %{name}-%{version}
%apply_patches

%build

# QEMU already knows how to set _FORTIFY_SOURCE
%global optflags %(echo %{optflags} | sed 's/-Wp,-D_FORTIFY_SOURCE=2//')

# --build-id option is used for giving info to the debug packages.
extraldflags="-Wl,--build-id";
buildldflags="VL_LDFLAGS=-Wl,--build-id"

buildarch="i386-softmmu x86_64-softmmu alpha-softmmu arm-softmmu \
cris-softmmu lm32-softmmu m68k-softmmu microblaze-softmmu \
microblazeel-softmmu mips-softmmu mipsel-softmmu mips64-softmmu \
mips64el-softmmu or32-softmmu ppc-softmmu ppcemb-softmmu ppc64-softmmu \
s390x-softmmu sh4-softmmu sh4eb-softmmu sparc-softmmu sparc64-softmmu \
xtensa-softmmu xtensaeb-softmmu unicore32-softmmu moxie-softmmu \
tricore-softmmu \
i386-linux-user x86_64-linux-user aarch64-linux-user alpha-linux-user \
arm-linux-user armeb-linux-user cris-linux-user m68k-linux-user \
microblaze-linux-user microblazeel-linux-user mips-linux-user \
mipsel-linux-user mips64-linux-user mips64el-linux-user \
mipsn32-linux-user mipsn32el-linux-user \
or32-linux-user ppc-linux-user ppc64-linux-user ppc64le-linux-user \
ppc64abi32-linux-user s390x-linux-user sh4-linux-user sh4eb-linux-user \
sparc-linux-user sparc64-linux-user sparc32plus-linux-user \
unicore32-linux-user aarch64-softmmu"

%if %{with x86only}
    buildarch="i386-softmmu x86_64-softmmu i386-linux-user x86_64-linux-user"
%endif

./configure \
	--prefix=%{_prefix} \
	--libdir=%{_libdir} \
	--sysconfdir=%{_sysconfdir} \
	--interp-prefix=%{_prefix}/qemu-%%M \
	--localstatedir=%{_localstatedir} \
	--libexecdir=%{_libexecdir} \
	--with-pkgversion=%{name}-%{version}-%{release} \
	--disable-strip \
	--extra-ldflags="$extraldflags -pie -Wl,-z,relro -Wl,-z,now" \
	--extra-cflags="%{optflags}" \
	--enable-pie \
	--disable-werror \
	--target-list="$buildarch" \
	--audio-drv-list=pa,sdl,alsa,oss \
	--enable-kvm \
	--enable-tcmalloc \
%if %{with spice}
	--enable-spice \
%else
	--disable-spice \
%endif
%if %{with seccomp}
	--enable-seccomp \
%else
	--disable-seccomp \
%endif
	--with-sdlabi="2.0" \
	--with-gtkabi="3.0" \
	--enable-vde \
	--disable-xen \
%if %{without rbd}
	--disable-rbd \
%endif
%if %{without fdt}
	--disable-fdt \
%endif
	"$@"

echo "config-host.mak contents:"
echo "==="
cat config-host.mak
echo "==="

%make V=1 $buildldflags

gcc %{SOURCE6} -O2 -g -o ksmctl

cat %{SOURCE4} | sed "s,@libexecdir@,%{_libexecdir},g" > ksm.service


%install
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig/modules
mkdir -p %{buildroot}%{_sysconfdir}/qemu
mkdir -p %{buildroot}%{_bindir}/
mkdir -p %{buildroot}%{_datadir}/%{name}
mkdir -p %{buildroot}%{_udevdir}

install -D -p -m 0644 ksm.service %{buildroot}/%{_unitdir}/ksm.service
install -D -p -m 0644 %{SOURCE5} %{buildroot}%{_sysconfdir}/sysconfig/ksm
install -D -p -m 0755 ksmctl %{buildroot}%{_libexecdir}/ksmctl

install -D -p -m 0644 %{SOURCE7} %{buildroot}/%{_unitdir}/ksmtuned.service
install -D -p -m 0755 %{SOURCE8} %{buildroot}%{_sbindir}/ksmtuned
install -D -p -m 0644 %{SOURCE9} %{buildroot}%{_sysconfdir}/ksmtuned.conf

install -D -p -m 0644 %{SOURCE10} %{buildroot}%{_unitdir}
install -D -p -m 0644 %{SOURCE11} %{buildroot}%{_udevdir}

%ifarch %{ix86} x86_64
install -m 0755 scripts/kvm/kvm_stat %{buildroot}%{_bindir}/
install -m 0644 %{SOURCE3} %{buildroot}%{_udevdir}
install -m 0755 %{SOURCE13} %{buildroot}%{_bindir}/qemu-kvm
%endif

%makeinstall_std

%ifarch %{ix86} x86_64
ln -sf qemu.1.xz %{buildroot}%{_mandir}/man1/qemu-kvm.1.xz
%endif

#chmod -x %{buildroot}%{_mandir}/man1/*
install -D -p -m 0644 -t %{buildroot}%{qemudocdir} Changelog README COPYING COPYING.LIB LICENSE
for emu in %{buildroot}%{_bindir}/qemu-system-*; do
    ln -sf qemu.1.xz %{buildroot}%{_mandir}/man1/$(basename $emu).1.xz
done

install -D -p -m 0644 qemu.sasl %{buildroot}%{_sysconfdir}/sasl2/qemu.conf

# Provided by package openbios
rm -rf %{buildroot}%{_datadir}/%{name}/openbios-ppc
rm -rf %{buildroot}%{_datadir}/%{name}/openbios-sparc32
rm -rf %{buildroot}%{_datadir}/%{name}/openbios-sparc64
# Provided by package SLOF
rm -rf %{buildroot}%{_datadir}/%{name}/slof.bin
# Provided by package ipxe
rm -rf %{buildroot}%{_datadir}/%{name}/pxe*rom
rm -rf %{buildroot}%{_datadir}/%{name}/efi*rom
# Provided by package seavgabios
rm -rf %{buildroot}%{_datadir}/%{name}/vgabios*bin
# Provided by package seabios
rm -rf %{buildroot}%{_datadir}/%{name}/bios.bin
rm -rf %{buildroot}%{_datadir}/%{name}/bios-256k.bin
rm -rf %{buildroot}%{_datadir}/%{name}/acpi-dsdt.aml
rm -rf %{buildroot}%{_datadir}/%{name}/q35-acpi-dsdt.aml
# Provided by package sgabios
rm -rf %{buildroot}%{_datadir}/%{name}/sgabios.bin

# the pxe gpxe images will be symlinks to the images on
# /usr/share/ipxe, as QEMU doesn't know how to look
# for other paths, yet.
pxe_link() {
  ln -s ../ipxe/$2.rom %{buildroot}%{_datadir}/%{name}/pxe-$1.rom
  ln -s ../ipxe.efi/$2.rom %{buildroot}%{_datadir}/%{name}/efi-$1.rom
}

pxe_link e1000 8086100e
pxe_link ne2k_pci 10ec8029
pxe_link pcnet 10222000
pxe_link rtl8139 10ec8139
pxe_link virtio 1af41000

rom_link() {
    ln -s $1 %{buildroot}%{_datadir}/%{name}/$2
}

rom_link ../seavgabios/vgabios-isavga.bin vgabios.bin
rom_link ../seavgabios/vgabios-cirrus.bin vgabios-cirrus.bin
rom_link ../seavgabios/vgabios-qxl.bin vgabios-qxl.bin
rom_link ../seavgabios/vgabios-stdvga.bin vgabios-stdvga.bin
rom_link ../seavgabios/vgabios-vmware.bin vgabios-vmware.bin
rom_link ../seavgabios/vgabios-virtio.bin vgabios-virtio.bin
rom_link ../seabios/bios.bin bios.bin
rom_link ../seabios/bios-256k.bin bios-256k.bin
rom_link ../seabios/acpi-dsdt.aml acpi-dsdt.aml
rom_link ../seabios/q35-acpi-dsdt.aml q35-acpi-dsdt.aml
rom_link ../sgabios/sgabios.bin sgabios.bin

# Install binfmt
mkdir -p %{buildroot}%{_exec_prefix}/lib/binfmt.d
for i in dummy \
%ifnarch %{ix86} x86_64
    qemu-i386 \
%endif
%ifnarch alpha
    qemu-alpha \
%endif
%ifnarch %{arm}
    qemu-arm \
%endif
    qemu-armeb \
    qemu-cris \
    qemu-microblaze qemu-microblazeel \
%ifnarch mips
    qemu-mips qemu-mips64 \
%endif
%ifnarch mipsel
    qemu-mipsel qemu-mips64el \
%endif
%ifnarch m68k
    qemu-m68k \
%endif
%ifnarch ppc ppc64 ppc64le
    qemu-ppc qemu-ppc64abi32 qemu-ppc64 \
%endif
%ifnarch sparc sparc64
    qemu-sparc qemu-sparc32plus qemu-sparc64 \
%endif
%ifnarch s390 s390x
    qemu-s390x \
%endif
%ifnarch sh4
    qemu-sh4 \
%endif
    qemu-sh4eb \
; do
  test $i = dummy && continue
  grep /$i:\$ %{SOURCE1} > %{buildroot}%{_exec_prefix}/lib/binfmt.d/$i.conf
  chmod 644 %{buildroot}%{_exec_prefix}/lib/binfmt.d/$i.conf
done < %{SOURCE1}

# Install rules to use the bridge helper with libvirt's virbr0
install -m 0644 %{SOURCE12} %{buildroot}%{_sysconfdir}/qemu/

# Remove unneeded libtool-generated files
find %{buildroot} -name '*.la' -or -name '*.a' | xargs rm -f

# Remove systemd-specific stuff, we do not use it yet
rm -rf %{buildroot}%{_datadir}/systemtap

%find_lang %{name}


%changelog

* Fri May 20 2016 Evgenii Shatokhin <eugene.shatokhin@rosalab.ru> 2.5.1.1-1
- (7615e0b) Updated to version 2.5.1.1 with additional patches from Mageia
- (7615e0b) The patches are for CVE-2016-2198, CVE-2016-2391, CVE-2016-2858,
- (7615e0b) CVE-2016-4001, CVE-2016-4002, CVE-2016-4020.

* Fri May 20 2016 Evgenii Shatokhin <eugene.shatokhin@rosalab.ru> 2.5.0-1
- (9f028cb) Fix the path to ksmctl in ksm.service
- (Evgenii Shatokhin: fccd4d8) Package the man page for QEMU guest agent
- (Evgenii Shatokhin: 0116d5c) Put the client and server tools for QEMU's ivshmem device into their own RPM
- (Evgenii Shatokhin: abc5334) Remove libcacard packages: they are in a separate project now
- (Evgenii Shatokhin: cacff14) Development files for EGL are needed for the build
- (Evgenii Shatokhin: ed154fc) Updated to version 2.5.0 with additional patches from Fedora
- (Evgenii Shatokhin: ed154fc) Changelog for version 2.5:
- (Evgenii Shatokhin: ed154fc) http://wiki.qemu.org/ChangeLog/2.5
- (Evgenii Shatokhin: ed154fc) The patches from Fedora fix several security and stability issues.

* Fri Feb 26 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.4.0-6
- (a0f5deb) Use systemd macros to control post-scripts

* Fri Feb 19 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.4.0-5
- (4d0939a) Bump release

* Sun Nov 15 2015 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.4.0-4
- (552cdf2) Spec cleanup
- (Andrey Bondrov: ee22b67) Enable VDE support

* Mon Sep 07 2015 Denis Silakov <denis.silakov@rosalab.ru> 2.4.0-3
- (7f37451) Require ipxe-roms-qemu >= 20150803, qemu fails with ancient package installed from main/release repository

* Thu Aug 20 2015 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 2.4.0-2
- (ee5b4bf) Conditionally enable SPICE support (support it in Fresh but not in Current)

* Thu Aug 20 2015 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 2.4.0-1
- (c3d0142) Removed a stray macro
- (Eugene Shatokhin: 3ed8a23) Updated the requirements for seabios, etc.
- (Eugene Shatokhin: fc15edc) Updated to version 2.4.0
- (Eugene Shatokhin: d73c00c) Fixed: develpment files for ALSA are needed, indeed
- (Eugene Shatokhin: d85977a) Updated to version 2.4.0-rc3 (based on Fedora packages)

* Sun Feb 22 2015 Alexander Lakhin <a.lahin@ntcit-rosa.ru> 1.5.0-7
- (d723cba) MassBuild#656: Increase release tag

* Fri Jan 16 2015 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 1.5.0-6
- (5ce0e7b) Build without SystemTap unconditionally

* Mon Dec 29 2014 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 1.5.0-5
- (d588856) Do not enable tracing
- (Eugene Shatokhin: a89dc45) Do not require brlapi-devel
- (Eugene Shatokhin: 90c1363) Disable SPICE, don't try to be too smart
- (Eugene Shatokhin: 8a49732) Disabled seccomp as well
- (Eugene Shatokhin: d3aa955) Build without SPICE support at the moment
- (Andrey Bondrov: adcb669) Try optional build for systemtap

* Wed Jul 23 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.5.0-4
- (0a2c075) Fix build with make 4.0

* Fri Jun 27 2014 Alex Burmashev <alex.burmashev@rosalab.ru> 1.5.0-3
- (d4f2c0c) MassBuild#440: Increase release tag

* Tue Jun 03 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.5.0-2
- (9147fa9) MassBuild#430: Increase release tag

* Tue May 06 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.5.0-1
- (c64155a) Update BuildRequires


